@@ -2,7 +2,7 @@
 #
 #  This file is part of Sequana software
 #
-#  Copyright (c) 2016-2020 - Sequana Development Team
+#  Copyright (c) 2016-2021 - Sequana Development Team
 #
 #  File author(s):
 #      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
@@ -20,11 +20,17 @@ import sys
 import re
 import argparse
 from pathlib import Path
-
 import parse
-
 import re
 
+
+import colorlog
+logger = colorlog.getLogger(__name__)
+
+
+__all__ = ['Development']
+
+
 class DebugJob:
     """Helper for sequana jobs debugging on slurm cluster.
 
@@ -44,9 +50,14 @@ class DebugJob:
         self.path = Path(path)
         self.context = context
         self.slurm_out = sorted([f for f in self.path.glob("slurm*.out")])
-        print("Found {} slurm files to introspect. Please wait.".format(len(self.slurm_out)))
+        print(
+            "Found {} slurm files to introspect. Please wait.".format(
+                len(self.slurm_out)
+            )
+        )
         if not self.slurm_out:
-            raise IOError(f"No slurm*.out files were found in {path}")
+            logger.warning(f"No slurm*.out files were found in {path}")
+            sys.exit(0)
 
         with open(self.slurm_out[0], "r") as f:
             self.snakemaster = f.read()
@@ -60,7 +71,7 @@ class DebugJob:
             if error:
                 self.n_errors += 1
                 ID = os.path.basename(x)
-                self.errors.append({'rule': "NA", 'slurm_id': ID, 'hint': error })
+                self.errors.append({"rule": "NA", "slurm_id": ID, "hint": error})
 
     def __repr__(self):
 
@@ -69,19 +80,25 @@ class DebugJob:
     def _report(self):
 
         message = "#" * 33 + " DEBUG REPORT " + "#" * 33 + "\n\n"
-        message += f"The analysis reached {self.percent}%. A total of {self.n_errors} errors has been found.\n\n"
+        message += f"The analysis reached {self.percent}%. A total of {self.n_errors} errors has been found.\n"
+        message += f"Errors are comming from rule(s): {','.join(set([e['rule'] for e in self.errors]))}\n\n"
 
         for e in self.errors:
 
-            if 'log' in e:
+            if "log" in e:
                 message += f"Rule: {e['rule']}, SlurmID: {e['slurm_id']}\n"
                 message += self._get_error_message(self.path / e["log"])
                 message += self._get_error_message(
                     self.path / ("slurm-" + str(e["slurm_id"]) + ".out")
                 )
-            if 'hint' in e:
+            if "hint" in e:
                 message += f" - slurm file: {e['slurm_id']}"
-                message += "; Hints: {}".format(e['hint'])
+                message += "; Hints: {}".format(e["hint"])
+            else:
+                message += f"Rule: {e['rule']}, SlurmID: {e['slurm_id']}\n"
+                message += self._get_error_message(
+                    self.path / ("slurm-" + str(e["slurm_id"]) + ".out")
+                )
 
         message += "\n" + "#" * 80
 
@@ -138,8 +155,19 @@ class DebugJob:
     log: {log:S} (check log file(s) for error message)
     cluster_jobid: Submitted batch job {slurm_id:d}"""
 
-        return list(parse.findall(errors, self.snakemaster))
+        parsed_errors = list(parse.findall(errors, self.snakemaster))
 
+        if parsed_errors:
+            return parsed_errors
+
+        else:
+
+            errors = """Error in rule {rule:S}:
+    jobid: {jobid:d}
+    output: {output}
+    cluster_jobid: Submitted batch job {slurm_id:d}"""
+
+        return list(parse.findall(errors, self.snakemaster))
 
     def _error_command_not_found(self, log_file):
         with open(log_file, "r") as f:
@@ -151,22 +179,34 @@ class DebugJob:
 class Options(argparse.ArgumentParser):
     def __init__(self, prog="sequana_slurm_status"):
         usage = """
+
     sequana_slurm_status
     sequana_slurm_status --directory ./rnaseq/
+
     """
 
-        super(Options, self).__init__(usage=usage, prog=prog,
+        super(Options, self).__init__(
+            usage=usage,
+            prog=prog,
             description="""This tool scan slurm jobs trying o infer useful
-summary of errorse""", formatter_class=argparse.ArgumentDefaultsHelpFormatter)
-
-        self.add_argument("--directory", type=str, default=".",
-            help="""Directory where to introspect slurm jobs""")
-        self.add_argument("--context", type=int, default=5,
-            help="""Number of errors to show""")
- 
+summary of errorse""",
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        )
 
+<<<<<<< HEAD
+=======
+        self.add_argument(
+            "--directory",
+            type=str,
+            default=".",
+            help="""Directory where to introspect slurm jobs""",
+        )
+        self.add_argument(
+            "--context", type=int, default=5, help="""Number of errors to show"""
+        )
 
 
+>>>>>>> 7c1ab6435e35d3fadf2ae3066514d2a35b3f102e
 def main(args=None):
 
     if args is None:
@@ -177,12 +217,11 @@ def main(args=None):
     if "--help" in args:
         user_options.parse_args(["prog", "--help"])
     else:
-       options = user_options.parse_args(args[1:])
+        options = user_options.parse_args(args[1:])
 
     dj = DebugJob(options.directory, context=options.context)
     print(dj)
 
+
 if __name__ == "__main__":
     main()
-
-
